# config.py -- dddcms config file.
# Copyright (c) 2009 Neels J. Hofmeyr
#
#  This file is part of dddcms.
#
#  dddcms is free software: you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  dddcms is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with dddcms.  If not, see <http://www.gnu.org/licenses/>.

# This is the "Home link" label on top of the navigation bar.
ROOT_LINK_LABEL = 'dddcms'

# Which port should ddd start on? (becomes e.g. http://localhost:8080/ )
DDD_PORT = 8080

# The user names and their passwords.
USERS = { 'admin': 'ddd',
        }

# Where is your database?
# What is the path of the folder that has all your content?
# If this is None, ddd will try to guess it automatically, assuming
# that you left the default directory structure:
#  your_ddd/.../ddd.py
# 'your_ddd' being the root of your content.
DB_FILE_SYSTEM_LOCATION = None

# What is the URL that leads to the root of dddcms on the web?
# If your dddcms is at the root of your server, you can just use:
ROOT_URL = None
# ROOT_URL = '/some/sub/dir'
# ROOT_URL = 'http://example.com/'
# ROOT_URL = 'http://example.com/some/sub/dir'

# Some hardcoded paths to definitely not show on the web.
# These are *no* globs, and they only match full paths relative
# to the db root.
# (Files you need to have in the db but don't want to publish ever)
# Note that you can't put javascript or css files or somesuch in a
# directory listed here, because these files need to be published.
# If you want that, use e.g. ITEMS_HIDDEN_NAME instead.
DB_EXLUDE = ['...',
             '.hg',
             '.hgignore',
            ]
# Hiding whole subtrees without db-root-paths "does not perform well".
# You cannot hide a subtree by hiding its parent -- subfolders are still
# visible if you supply the URL explicitly.
# If you wanted to implement that, think again. That would mean to check
# each and every parent path element's control files.
# *If you want to hide something, don't put it in the db.*
# This DB_EXLUDE is for things that you *can't* just move away.

# How many levels of parent directories to show altogether, and how
# many of them to show complete with children.
# The indentation per level is defined in ./scripts/style.css.
# NOTE: If you need more that 7 parent levels, you need to also adjust
# the .scripts/style.css and add some more "levelN" styles as needed.
NAV_MAX_LEVELS = 5
NAV_MAX_EXPANDED_LEVELS = 3

# text content file name.
#   ddd/my_hobbies/_text
# Contains HTML markup (whatever lives inside <body> </body> tags)
TEXT_CONTENT_NAME = '_text'

# Attachments directory name.
#   ddd/my_hobbies/_files/
# By default, "all" files in ddd/my_hobbies/ are treated as attachments.
# If you don't want that, you can create a folder to contain explicit
# attachments. This is the name of that folder.
FILES_DIR_NAME = '_files'

# This works exactly like FILES_DIR_NAME -- if you want to hide some
# image files, create a folder named like this and put those images that
# should be shown (if any) into this folder.
PHOTOS_DIR_NAME = '_photos'
# Note that files in this directory that *do not* end with a known image
# suffix are simply ignored.

# Ordering list file name.
#   ddd/my_hobbies/_sort
# By default, all subfolders in my_hobbies/ will be listed as sub-items
# in alphabetical order. If you want to change the order create a file
# named like this:
SORT_NAME = '_sort'
# It should hold one filename per line. An easy way to create an initial
# list is to go to directory my_hobbies/ and do `ls -1 > _sort'. Edit
# that file to create the desired order.
# Any folders that are not listed in the _sort file will be appended to
# the navigation list after all ordered items.

# If you have only a few files to exclude, put them in a file named like
# this:
ITEMS_HIDDEN_NAME = '_hidden'
# Note that this does *not* effectively hide any items, it just omits
# them from the navigation. If a URL requests these items directly, they
# are happily displayed.

# Each file (image or any other file type) can have a description.
# It is shown "next to" the file in the file listing, and for images,
# this description is shown in the photo view.
# This is a folder, containing files with the exact names of the files
# they are describing but with '.' attached:
ANNOTATIONS_DIR_NAME = '_annotations'
# e.g.
#   ddd/my_hobbies/paddling.jpg                        <-- image
#   ddd/my_hobbies/_annotations/paddling.jpg.          <-- description text
# where the first is the real image and the second is a text file with
# the same name. These text files are composed in HTML markup.

# This is the suffix that has to be appended to the filename of an
# annotation. (see above)
ANNOTATION_SUFFIX = '.'
# The suffix is added to prevent common tools from mistaking annotations
# for image files. You can use an empty suffix if you like:
# ANNOTATION_SUFFIX = ''


# you can also change the alphabetical order sorting to some other.
# This function receives two instances of Path (helpers.py) and compares.
ITEMS_CMP = lambda a,b: cmp(a.basename(), b.basename())

# If an attached file has a suffix like this, it is put in the photos view
# of that item.
# Gallery files can also be sorted using _sort.
PHOTO_SUFFIXES = ['.png', '.jpg', '.gif', '.jpeg', '.bmp', '.ico', ]

# If this is False, the PHOTO_SUFFIXES match both upper and lower case:
PHOTO_SUFFIXES_ARE_CASE_SENSITIVE = False

# The thumb will be scaled to fit into a square of this pixel length:
THUMBS_SIZE = '53x53'

# When viewing a photo in a photo gallery, it is scaled to fit in this size:
LORES_SIZE = '720x540'

# The date format used for the last-modification-time on the web.
# see python's time.strftime()
# http://docs.python.org/library/time.html#time.strftime
DATE_FORMAT = '%Y-%m-%d %H:%M'


# The script-relative or absolute location of the templates.
TEMPLATES_DIR = "templates"

# ddd will keep a thumbnail cache of your images. This is where it keeps
# the cached thumbs
THUMBS_DIR = '.image-thumbs'

# Same for low-resolution views of the images.
LO_RES_DIR = '.image-views'


# These are the names used in a url to request the photo gallery view and
# the low-resolution version of an image file, respectively. E.g. in
#   http://example.com/summer/hot.jpg?photos
# this is the name used after the '?', here 'photos'.
PHOTO_VIEW_ARG = 'photos'
LO_RES_ARG = 'lores'

# Other '?name' arguments.
EDIT_ARG = 'do_edit'
ADD_ARG = 'do_add'
REMOVE_ARG = 'do_remove'
CONFIG_ARG = 'do_config'
LOGOUT_ARG = 'do_logout'
LOGIN_ARG = 'do_login'

DIALOG_ID_NAME = 'dialog_id'

DIALOG_LOGIN_NAME_ARG = 'login_name'
DIALOG_LOGIN_PASS_ARG = 'login_pass'

DIALOG_ADD_NAME_ARG = 'add_name'

DIALOG_EDIT_TEXT = 'edit_text'

DIALOG_ITEMCONFIG_PHOTO_VIEW = 'item_config_photos_view'
DIALOG_ITEMCONFIG_RENAME = 'item_config_rename'
DIALOG_ITEMCONFIG_COPY = 'item_config_copy'
DIALOG_ITEMCONFIG_ITEMS = 'item_config_items'
DIALOG_ITEMCONFIG_ITEMS_APPEND = 'item_config_items_append'

# This is a filesystem path relative to ddd.py's parent or absolute.
FAVICON_PATH = 'favicon.ico'

# ddd never physically removes any content. Instead, items that a user
# "removes" via the web interface are moved to a trash directory. This
# is the name of that directory.
# It is either an absolute file system path, or
# a path relative to the db root.
# If you don't like to keep a lot of trash, consider a path like
# '/tmp/ddd-trash'. However, if /tmp is on a different filesystem, that
# may be an unwise choice, since data will be moved there.
# If you like your trash to be visible on the web, use a relative
# path (not starting with a /).
# By default, it is published but hidden from the nav inside .caches/
# -- to see the trash, add '.trash/' to your ddd root URL
#     http://localhost:8080/.trash/
TRASH_PATH = '.trash'

# If a user points the browser at a trash URL, ddd will create thumbs
# and lo-res versions of those images *as well* -- but you can switch it
# off by setting this value to False:
PREVIEW_IMAGES_IN_TRASH = True

# If this is a path, a sessions directory will be used for sessions.
# This can (, again,) be either an absolute file system path, or
# a path relative to the ddd.py script's parent directory.
SESSIONS_DIR = 'sessions'
# If this is None, sessions will be stored in RAM.

# The session timeout in minutes
SESSIONS_TIMEOUT = 180

DELETE_BUTTON_LABEL = 'Move to Trash'
